# Generated by Django 4.0.3 on 2022-04-27 06:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0005_backlog_privatenotice'),
    ]

    operations = [
        migrations.AddField(
            model_name='backlog',
            name='creator',
            field=models.CharField(max_length=64, null=True, verbose_name='creator'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='title',
            field=models.CharField(max_length=64, null=True, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='privatenotice',
            name='creator',
            field=models.CharField(max_length=64, null=True, verbose_name='creator'),
        ),
    ]
