# Generated by Django 4.0.3 on 2022-04-19 08:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0002_remove_noticestore_receiver_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='receivertag',
            name='receiver_id',
        ),
        migrations.AddField(
            model_name='receivertag',
            name='receiver',
            field=models.CharField(default='', max_length=64, verbose_name='receiver'),
            preserve_default=False,
        ),
    ]
