# Generated by Django 4.0.3 on 2022-05-27 09:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0009_rename_handler_backlog_handlers_backlog_cc_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='backlog',
            name='cc',
        ),
        migrations.RemoveField(
            model_name='backlog',
            name='cc_type',
        ),
        migrations.AddField(
            model_name='backlog',
            name='initiated_at',
            field=models.DateTimeField(null=True, verbose_name='initiated datetime'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_associated_data',
            field=models.CharField(max_length=64, null=True, verbose_name='obj associated data'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_associated_data_type',
            field=models.CharField(max_length=64, null=True, verbose_name='obj associated data type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_node',
            field=models.CharField(max_length=64, null=True, verbose_name='obj node'),
        ),
    ]
