# Generated by Django 4.0.3 on 2022-05-07 10:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0007_remove_privatenotice_content_and_more'),
    ]

    operations = [

        migrations.RemoveField(
            model_name='backlog',
            name='title',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='business_type',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='is_node_done',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='node',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='obj_key',
        ),
    ]
