# Generated by Django 4.0.3 on 2022-05-29 03:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0010_remove_backlog_cc_remove_backlog_cc_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='backlog',
            name='obj_node',
        ),
        migrations.AddField(
            model_name='backlog',
            name='is_deleted',
            field=models.BooleanField(default=False, verbose_name='delete tag'),
        ),
    ]
