# Generated by Django 4.0.3 on 2022-04-19 09:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0003_remove_receivertag_receiver_id_receivertag_receiver'),
    ]

    operations = [
        migrations.AlterField(
            model_name='receivertag',
            name='noticestore',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='notice.noticestore', verbose_name='notice'),
        ),
    ]
