# Generated by Django 4.0.3 on 2022-05-27 08:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0008_remove_backlog_redirect_url_remove_backlog_title_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='backlog',
            old_name='handler',
            new_name='handlers',
        ),
        migrations.AddField(
            model_name='backlog',
            name='cc',
            field=models.CharField(max_length=64, null=True, verbose_name='cc'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='cc_type',
            field=models.CharField(max_length=64, null=True, verbose_name='cc type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='company',
            field=models.CharField(max_length=64, null=True, verbose_name='company type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='company_type',
            field=models.CharField(max_length=64, null=True, verbose_name='company type'),
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='content',
            field=models.TextField(null=True, verbose_name='content'),
        ),
    ]
